##  Introduction
The integration between SAP LeanIX and Collibra facilitates mapping applications, business capabilities, and interfaces from SAP LeanIX to Collibra, enhancing transparency and insights within Collibra. This improves the business perspective and lineage support of your data governance practice by connecting SAP LeanIX's business-centric data with Collibra's governance framework.
![Fact Sheet Mapping from SAP LeanIX to Collibra](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750d8767a4410148f86c415bc80d6b2_LowRes.png)
Fact Sheet Mapping from SAP LeanIX to Collibra
